This directory contains the following example scripts:

- `parsing_tla_modules.py`: how to parse a TLA+ module
- `parsing_tla_expressions.py`: how to parse a TLA+ expression
- `syntax_tree_visitor.py`: how to implement the visitor pattern using the
  TLA+ abstract syntax tree
